'''
Author: LetMeFly
Date: 2022-01-24 15:55:51
LastEditors: LetMeFly
LastEditTime: 2022-01-24 16:46:13
'''
import requests


def submit(cid: str, pid: str, cookies: requests.cookies.RequestsCookieJar, code: str) -> None:
    url = "http://182.92.175.181/submit.php"
    data = {
        'cid': cid,
        'pid': pid,
        'language': '1',  # C++
        'source': code
    }
    response = requests.post(url, data=data, cookies=cookies)
    



'''
Author: LetMeFly
Date: 2022-01-24 15:01:27
LastEditors: LetMeFly
LastEditTime: 2022-01-26 11:00:58
Description: 获取某场比赛的题面数量
'''
import requests
from bs4 import BeautifulSoup

try:
    import lxml
    features = 'lxml'
except:
    features = None


def getContestProblemList(cid: str, cookies='') -> int:
    response = requests.get('http://182.92.175.181/contest.php?cid='+str(cid), cookies=cookies)
    soup = BeautifulSoup(response.text, features)
    table = soup.find('table')
    return len(table.find('tbody').find_all('tr'))



'''
Author: LetMeFly
Date: 2022-01-24 14:57:01
LastEditors: LetMeFly
LastEditTime: 2022-01-24 14:59:11
'''
import hashlib
import requests


def password2md5(passowrd):
    return hashlib.md5(str(passowrd).encode('utf-8')).hexdigest()


def login(user_id: str, password: str) -> requests.cookies.RequestsCookieJar:
    """
    通过账号和密码返回cookie
    """
    url = 'http://182.92.175.181/login.php'
    data = {'user_id': user_id, 'password': password2md5(password)}
    response = requests.post(url, data=data)
    return response.cookies
